@@ -17,7 +17,7 @@
  *   GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, see <http://www.gnu.org/licenses/>.
+ *   along with this program; if not, see <https://www.gnu.org/licenses/>.
  */
 .pragma library
 .import "qrc:/gcompris/src/core/core.js" as Core
@@ -711,6 +711,11 @@ function initLevel() {
                       .arg(priceText)
 
     }
+
+    //Keyboard reset
+    items.itemIndex = -1
+    items.selectedArea = items.pocket
+
 }
 
 // Given a price return a random object
