@@ -17,7 +17,7 @@
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
- along with this program; if not, see <http://www.gnu.org/licenses/>.
+ along with this program; if not, see <https://www.gnu.org/licenses/>.
 */
 
 .pragma library
@@ -251,8 +251,8 @@ function planeMove() {
     if(items.plane.y < 0) {
         items.plane.y = 0;
     }
-    if(items.plane.y + items.plane.height > items.background.height) {
-        items.plane.y = items.background.height - items.plane.height;
+    if(items.plane.y + items.plane.height > items.background.height - items.bar.height) {
+        items.plane.y = items.background.height - (items.plane.height + items.bar.height);
     }
 
 }
