@@ -1,4 +1,4 @@
-/* GCompris - ApplicationSettingsDefault.cpp
+/* GCompris - ApplicationInfo.h
  *
  * Copyright (C) 2014-2015 Bruno Coudoin <bruno.coudoin@gcompris.net>
  *
@@ -19,7 +19,7 @@
  *   GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, see <http://www.gnu.org/licenses/>.
+ *   along with this program; if not, see <https://www.gnu.org/licenses/>.
  */
 #ifndef APPLICATIONINFO_H
 #define APPLICATIONINFO_H
@@ -28,7 +28,6 @@
 #include "ApplicationSettings.h"
 
 #include <QObject>
-#include <QQmlPropertyMap>
 #include <QQmlEngine>
 #include <QtGlobal>
 
@@ -107,7 +106,7 @@ class ApplicationInfo : public QObject
 	/**
 	 * Short (2-letter) locale string of the currently active language.
 	 */
-	Q_PROPERTY(QString localeShort READ localeShort)
+	Q_PROPERTY(QString localeShort READ localeShort CONSTANT)
 
     /**
      * GCompris version string (compile time).
@@ -145,7 +144,7 @@ class ApplicationInfo : public QObject
      *
      * Use to deactivate some effects if OpenGL not used.
      */
-	Q_PROPERTY(bool useOpenGL READ useOpenGL CONSTANT)
+    Q_PROPERTY(bool useOpenGL READ useOpenGL WRITE setUseOpenGL NOTIFY useOpenGLChanged)
         
 public:
 
@@ -164,15 +163,6 @@ public:
 
     Q_ENUM(Platform)
 
-    /**
-     * Registers singleton in the QML engine.
-     *
-     * It is not recommended to create a singleton of Qml Singleton registered
-     * object but we could not found a better way to let us access ApplicationInfo
-     * on the C++ side. All our test shows that it works.
-     */
-    static void init();
-
     /**
      * Returns an absolute and platform independent path to the passed @p file
      *
@@ -221,15 +211,6 @@ public:
      */
     Q_INVOKABLE void abandonAudioFocus() const;
 
-    /**
-     * Return the platform specific path for storing data shared between apps
-     *
-     * On Android: /storage/emulated/0/GCompris (>= Android 4.2),
-     *             /storage/sdcard0/GCompris (< Android 4.2)
-     * On Linux: $HOME/local/share/GCompris
-     */
-    Q_INVOKABLE QString getSharedWritablePath() const;
-
     /**
      * Compare two strings respecting locale specific sort order.
      *
@@ -264,16 +245,16 @@ public:
         }
         return m_instance;
     }
-    static QObject *systeminfoProvider(QQmlEngine *engine,
-									   QJSEngine *scriptEngine);
+    static QObject *applicationInfoProvider(QQmlEngine *engine,
+                                            QJSEngine *scriptEngine);
     static void setWindow(QQuickWindow *window);
     explicit ApplicationInfo(QObject *parent = 0);
     ~ApplicationInfo();
-	int applicationWidth() const { return m_applicationWidth; }
-	void setApplicationWidth(const int newWidth);
+    int applicationWidth() const { return m_applicationWidth; }
+    void setApplicationWidth(const int newWidth);
     Platform platform() const { return m_platform; }
-	bool isPortraitMode() const { return m_isPortraitMode; }
-	void setIsPortraitMode(const bool newMode);
+    bool isPortraitMode() const { return m_isPortraitMode; }
+    void setIsPortraitMode(const bool newMode);
     bool isMobile() const { return m_isMobile; }
     bool hasShader() const {
 #if defined(Q_OS_ANDROID)
@@ -282,7 +263,7 @@ public:
         return true;
 #endif
     }
-	qreal ratio() const { return m_ratio; }
+    qreal ratio() const { return m_ratio; }
     qreal fontRatio() const { return m_fontRatio; }
     QString localeShort() const {
         return localeShort( ApplicationSettings::getInstance()->locale() );
@@ -292,13 +273,8 @@ public:
     static QString QTVersion() { return qVersion(); }
     static QString CompressedAudio() { return COMPRESSED_AUDIO; }
     static bool isDownloadAllowed() { return QString(DOWNLOAD_ALLOWED) == "ON"; }
-    static bool useOpenGL() { 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 8, 0)
-        return QString(GRAPHICAL_RENDERER) != "software"; 
-#else
-        return true;
-#endif
-    }
+    bool useOpenGL() const { return m_useOpenGL; }
+    void setUseOpenGL(bool useOpenGL) { m_useOpenGL = useOpenGL; }
 
     /**
      * Returns the native screen orientation.
@@ -386,7 +362,7 @@ protected slots:
      *             Any occurrence of '$CA' placeholder will be replaced by
      *             the current compressed audio format ('ogg' or 'aac).
      *             Example: 'voices-$CA/$LOCALE/misc/click_on_letter.$CA'
-     * @param locale the locale for which to get this audio file
+     * @param localeName the locale for which to get this audio file
      * @returns An absolute path to the corresponding resource file.
      */
     Q_INVOKABLE QString getAudioFilePathForLocale(const QString &file,
@@ -422,24 +398,25 @@ protected slots:
     Q_INVOKABLE void notifyFullscreenChanged();
 
 protected:
-	qreal getSizeWithRatio(const qreal height) { return ratio() * height; }
+    qreal getSizeWithRatio(const qreal height) { return ratio() * height; }
 
 signals:
-	void applicationWidthChanged();
-	void portraitModeChanged();
-	void ratioChanged();
+    void applicationWidthChanged();
+    void portraitModeChanged();
+    void ratioChanged();
     void fontRatioChanged();
     void applicationSettingsChanged();
     void fullscreenChanged();
+    void useOpenGLChanged();
 
 private:
     static ApplicationInfo *m_instance;
     int m_applicationWidth;
     Platform m_platform;
-	QQmlPropertyMap *m_constants;
-	bool m_isPortraitMode;
-	bool m_isMobile;
-	qreal m_ratio;
+    bool m_isPortraitMode;
+    bool m_isMobile;
+    bool m_useOpenGL;
+    qreal m_ratio;
     qreal m_fontRatio;
 
     // Symbols fonts that user can't see
