@@ -16,7 +16,7 @@
  *   GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, see <http://www.gnu.org/licenses/>.
+ *   along with this program; if not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "DownloadManager.h"
@@ -33,22 +33,22 @@
 
 #include <QtQml>
 
-const QString DownloadManager::contentsFilename = QString("Contents");
-DownloadManager* DownloadManager::_instance = 0;
+const QString DownloadManager::contentsFilename = QStringLiteral("Contents");
+DownloadManager* DownloadManager::_instance = nullptr;
 
-void copyPath(QString src, QString dst)
+void copyPath(const QString &src, const QString &dst)
 {
     QDir dir(src);
     if (!dir.exists())
         return;
 
-    Q_FOREACH(const QString &d, dir.entryList(QDir::Dirs | QDir::NoDotAndDotDot)) {
+    for(const QString &d : dir.entryList(QDir::Dirs | QDir::NoDotAndDotDot)) {
         QString dst_path = dst + QDir::separator() + d;
         dir.mkpath(dst_path);
-        copyPath(src+ QDir::separator() + d, dst_path);
+        copyPath(src + QDir::separator() + d, dst_path);
     }
 
-    Q_FOREACH(const QString &f, dir.entryList(QDir::Files)) {
+    for(const QString &f : dir.entryList(QDir::Files)) {
         qDebug() << "Copying " << src + QDir::separator() + f << " to " << dst + QDir::separator() + f;
         QFile::copy(src + QDir::separator() + f, dst + QDir::separator() + f);
     }
@@ -64,8 +64,7 @@ DownloadManager::DownloadManager()
         QStandardPaths::writableLocation(QStandardPaths::DataLocation) + "/data" <<
         QStandardPaths::writableLocation(QStandardPaths::DataLocation) + "/data2";
 
-    for(auto it = previousDataLocations.begin(); it != previousDataLocations.end() ; ++ it) {
-        QDir &prevDir = *it;
+    for(QDir &prevDir: previousDataLocations) {
         if(prevDir.exists()) {
             if(prevDir.dirName() == "data2") {
                 qDebug() << "Data changed place, move from previous folder to the new one";
@@ -80,7 +79,7 @@ DownloadManager::DownloadManager()
 DownloadManager::~DownloadManager()
 {
     shutdown();
-    _instance = 0;
+    _instance = nullptr;
 }
 
 void DownloadManager::shutdown()
@@ -95,12 +94,12 @@ void DownloadManager::shutdown()
 // Using the singleton after the QmlEngine has been destroyed is forbidden!
 DownloadManager* DownloadManager::getInstance()
 {
-    if (!_instance)
+    if (_instance == nullptr)
         _instance = new DownloadManager;
     return _instance;
 }
 
-QObject *DownloadManager::systeminfoProvider(QQmlEngine *engine,
+QObject *DownloadManager::downloadManagerProvider(QQmlEngine *engine,
         QJSEngine *scriptEngine)
 {
     Q_UNUSED(engine)
@@ -109,26 +108,19 @@ QObject *DownloadManager::systeminfoProvider(QQmlEngine *engine,
     return getInstance();
 }
 
-void DownloadManager::init()
-{
-    qmlRegisterSingletonType<DownloadManager>("GCompris", 1, 0,
-            "DownloadManager",
-            systeminfoProvider);
-}
-
 bool DownloadManager::downloadIsRunning() const
 {
-    return (activeJobs.size() > 0);
+    return !activeJobs.empty();
 }
 
 void DownloadManager::abortDownloads()
 {
-    if (activeJobs.size() > 0) {
+    if (downloadIsRunning()) {
         QMutexLocker locker(&jobsMutex);
         QMutableListIterator<DownloadJob*> iter(activeJobs);
         while (iter.hasNext()) {
             DownloadJob *job = iter.next();
-            if (job->reply) {
+            if (job->reply != nullptr) {
                 disconnect(job->reply, SIGNAL(finished()), this, SLOT(downloadFinished()));
                 disconnect(job->reply, SIGNAL(error(QNetworkReply::NetworkError)),
                         this, SLOT(handleError(QNetworkReply::NetworkError)));
@@ -138,12 +130,12 @@ void DownloadManager::abortDownloads()
                     job->file.close();
                     job->file.remove();
                 }
-                delete job->reply;
+                job->reply->deleteLater();
             }
             iter.remove();
         }
         locker.unlock();
-        emit error(QNetworkReply::OperationCanceledError, "Download cancelled by user");
+        emit error(QNetworkReply::OperationCanceledError, QObject::tr("Download cancelled by user"));
     }
 }
 
@@ -181,17 +173,15 @@ bool DownloadManager::updateResource(const QString& path)
 {
     if (checkDownloadRestriction())
         return downloadResource(path);  // check for updates and register
-    else {
-        QString absPath = getAbsoluteResourcePath(path);
-        // automatic download prohibited -> register if available
-        if (!absPath.isEmpty())
-            return registerResourceAbsolute(absPath);
-        else {
-            qDebug() << "No such local resource and download prohibited:"
-                << path;
-            return false;
-        }
-    }
+
+    QString absPath = getAbsoluteResourcePath(path);
+    // automatic download prohibited -> register if available
+    if (!absPath.isEmpty())
+        return registerResourceAbsolute(absPath);
+
+    qDebug() << "No such local resource and download prohibited: "
+             << path;
+    return false;
 }
 
 bool DownloadManager::downloadResource(const QString& path)
@@ -200,7 +190,7 @@ bool DownloadManager::downloadResource(const QString& path)
     {
         QMutexLocker locker(&jobsMutex);
         QUrl url(serverUrl.toString() + '/' + path);
-        if (getJobByUrl_locked(url)) {
+        if (getJobByUrl_locked(url) != nullptr) {
             qDebug() << "Download of" << url << "is already running, skipping second attempt.";
             return false;
         }
@@ -309,14 +299,14 @@ bool DownloadManager::download(DownloadJob* job)
     QDir dir;
     if (!dir.exists(fi.path()) && !dir.mkpath(fi.path())) {
         qDebug() << "Could not create resource path " << fi.path();
-        emit error(QNetworkReply::ProtocolUnknownError, "Could not create resource path");
+        emit error(QNetworkReply::ProtocolUnknownError, QObject::tr("Could not create resource path"));
         return false;
     }
 
     job->file.setFileName(tempFilenameForFilename(fi.filePath()));
     if (!job->file.open(QIODevice::WriteOnly)) {
         emit error(QNetworkReply::ProtocolUnknownError,
-                QString("Could not open target file %1").arg(job->file.fileName()));
+                QObject::tr("Could not open target file %1").arg(job->file.fileName()));
         return false;
     }
 
@@ -340,18 +330,18 @@ bool DownloadManager::download(DownloadJob* job)
 
 inline DownloadManager::DownloadJob* DownloadManager::getJobByUrl_locked(const QUrl& url) const
 {
-    for (int i = 0; i < activeJobs.size(); i++)
-        if (activeJobs[i]->url == url || activeJobs[i]->queue.indexOf(url) != -1)
-            return activeJobs[i];
+    for (auto activeJob : activeJobs)
+        if (activeJob->url == url || activeJob->queue.indexOf(url) != -1)
+            return activeJob;
     return nullptr;
 }
 
 inline DownloadManager::DownloadJob* DownloadManager::getJobByReply(QNetworkReply *r)
 {
     QMutexLocker locker(&jobsMutex);
-    for (int i = 0; i < activeJobs.size(); i++)
-        if (activeJobs[i]->reply == r)
-            return activeJobs[i];
+    for (auto activeJob : activeJobs)
+        if (activeJob->reply == r)
+            return activeJob;
     return nullptr;  // should never happen!
 }
 
@@ -421,6 +411,7 @@ void DownloadManager::handleError(QNetworkReply::NetworkError code)
 {
     Q_UNUSED(code);
     QNetworkReply *reply = dynamic_cast<QNetworkReply*>(sender());
+    qDebug() << reply->errorString() << " " << reply->error();
     emit error(reply->error(), reply->errorString());
 }
 
@@ -456,7 +447,7 @@ bool DownloadManager::parseContents(DownloadJob *job)
 
 bool DownloadManager::checksumMatches(DownloadJob *job, const QString& filename) const
 {
-    Q_ASSERT(job->contents != (QMap<QString, QString>()));
+    Q_ASSERT(!job->contents.empty());
 
     if (!QFile::exists(filename))
         return false;
@@ -506,22 +497,22 @@ bool DownloadManager::registerResourceAbsolute(const QString& filename)
     if (!QResource::registerResource(filename)) {
         qDebug() << "Error registering resource file" << filename;
         return false;
-    } else {
-        qDebug() << "Successfully registered resource"
-                << filename;
-        registeredResources.append(filename);
-
-        locker.unlock(); /* note: we unlock before emitting to prevent
-                          * potential deadlocks */
-
-        emit resourceRegistered(getRelativeResourcePath(filename));
-
-        QString v = getVoicesResourceForLocale(
-                    ApplicationSettings::getInstance()->locale());
-        if (v == getRelativeResourcePath(filename))
-            emit voicesRegistered();
-        return true;
     }
+
+    qDebug() << "Successfully registered resource"
+             << filename;
+    registeredResources.append(filename);
+
+    locker.unlock(); /* note: we unlock before emitting to prevent
+                      * potential deadlocks */
+
+    emit resourceRegistered(getRelativeResourcePath(filename));
+
+    QString v = getVoicesResourceForLocale(
+                     ApplicationSettings::getInstance()->locale());
+    if (v == getRelativeResourcePath(filename))
+        emit voicesRegistered();
+    return true;
 }
 
 /*
@@ -556,37 +547,40 @@ void DownloadManager::downloadFinished()
         job->file.flush();  // note: important, or checksums might be wrong!
         job->file.close();
     }
-    if (reply->error() && job->file.exists())
+
+    if (reply->error() != 0 && job->file.exists()) {
         job->file.remove();
+    }
     else {
         // active temp file
         QString tFilename = filenameForTempFilename(job->file.fileName());
-        if (QFile::exists(tFilename))
+        if (QFile::exists(tFilename)) {
             QFile::remove(tFilename);
-        if (!job->file.rename(tFilename))
+        }
+        if (!job->file.rename(tFilename)) {
             qWarning() << "Could not rename temporary file to" << tFilename;
+        }
     }
 
     QString targetFilename = getFilenameForUrl(job->url);
     if (job->url.fileName() == contentsFilename) {
         // Contents
-        if (reply->error()) {
+        if (reply->error() != 0) {
             qWarning() << "Error downloading Contents from" << job->url
                     << ":" << reply->error() << ":" << reply->errorString();
             // note: errorHandler() emit's error!
-            code = Error;
             goto outError;
         }
         //qDebug() << "Download of Contents finished successfully: " << job->url;
         if (!parseContents(job)) {
             qWarning() << "Invalid format of Contents file" << job->url;
-            emit error(QNetworkReply::UnknownContentError, "Invalid format of Contents file");
-            code = Error;
+            emit error(QNetworkReply::UnknownContentError, QObject::tr("Invalid format of Contents file"));
             goto outError;
         }
     } else {
+        QUrl redirect = reply->attribute(QNetworkRequest::RedirectionTargetAttribute).toUrl();
         // RCC file
-        if (reply->error()) {
+        if (reply->error() != 0) {
             qWarning() << "Error downloading RCC file from " << job->url
                 << ":" << reply->error() << ":" << reply->errorString();
             // note: errorHandler() emit's error!
@@ -594,13 +588,27 @@ void DownloadManager::downloadFinished()
             // register already existing files (if not yet done):
             if (QFile::exists(targetFilename) && !isRegistered(targetFilename))
                 registerResourceAbsolute(targetFilename);
-        } else {
+        }
+        // In case the file does not exist on the server, it is redirected to
+        // an error page and this error page is downloaded but on our case
+        // this is an error as we don't have the expected rcc.
+        else if (!redirect.isEmpty()) {
+            qWarning() << QString("The url %1 does not exist.").arg(job->url.toString());
+            emit error(QNetworkReply::UnknownContentError,
+                       QObject::tr("The url %1 does not exist.")
+                       .arg(job->url.toString()));
+            code = Error;
+            if (QFile::exists(targetFilename)) {
+                QFile::remove(targetFilename);
+            }
+        }
+        else {
             qDebug() << "Download of RCC file finished successfully: " << job->url;
             if (!checksumMatches(job, targetFilename)) {
                 qWarning() << "Checksum of downloaded file does not match: "
                         << targetFilename;
                 emit error(QNetworkReply::UnknownContentError,
-                        QString("Checksum of downloaded file does not match: %1")
+                        QObject::tr("Checksum of downloaded file does not match: %1")
                             .arg(targetFilename));
                 code = Error;
             } else
@@ -640,7 +648,7 @@ void DownloadManager::downloadFinished()
         activeJobs.removeOne(job);
     }
     emit downloadFinished(code);
-    delete reply;
+    reply->deleteLater();
     delete job;
     return;
 
@@ -652,7 +660,7 @@ void DownloadManager::downloadFinished()
         while (!job->queue.isEmpty()) {
             nUrl = job->queue.takeFirst();
             QString relPath = getRelativeResourcePath(getFilenameForUrl(nUrl));
-            foreach (const QString &base, getSystemResourcePaths()) {
+            for (const QString &base: getSystemResourcePaths()) {
                 QString filename = base + '/' + relPath;
                 if (QFile::exists(filename))
                     registerResourceAbsolute(filename);
@@ -668,13 +676,13 @@ void DownloadManager::downloadFinished()
         activeJobs.removeOne(job);
     }
 
-    delete reply;
+    reply->deleteLater();
     delete job;
     return;
 
   outNext:
     // next sub-job started
-    delete reply;
+    reply->deleteLater();
     return;
 }
 
