@@ -16,7 +16,7 @@
  *   GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, see <http://www.gnu.org/licenses/>.
+ *   along with this program; if not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef DOWNLOADMANAGER_H
@@ -222,9 +222,8 @@ public:
     /**
      * Registers DownloadManager singleton in the QML engine.
      */
-    static void init();
-    static QObject *systeminfoProvider(QQmlEngine *engine,
-            QJSEngine *scriptEngine);
+    static QObject *downloadManagerProvider(QQmlEngine *engine,
+                                            QJSEngine *scriptEngine);
     static DownloadManager* getInstance();
 
     /**
