@@ -16,7 +16,7 @@
  *   GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, see <http://www.gnu.org/licenses/>.
+ *   along with this program; if not, see <https://www.gnu.org/licenses/>.
  */
 #include <QtDebug>
 #include <QApplication>
@@ -30,22 +30,21 @@
 #include <QPixmap>
 #include <QSettings>
 
+#include "GComprisPlugin.h"
 #include "ApplicationInfo.h"
 #include "ActivityInfoTree.h"
-#include "File.h"
-#include "Directory.h"
 #include "DownloadManager.h"
 
 bool loadAndroidTranslation(QTranslator &translator, const QString &locale)
 {
-    QFile file("assets:/gcompris_" + locale + ".qm");
+    QFile file("assets:/share/GCompris/gcompris_" + locale + ".qm");
 
     file.open(QIODevice::ReadOnly);
     QDataStream in(&file);
     uchar *data = (uchar*)malloc(file.size());
 
     if(!file.exists())
-        qDebug() << "file assets:/" << locale << ".qm does not exist";
+        qDebug() << "file assets:/share/GCompris/gcompris_" << locale << ".qm does not exist";
 
     in.readRawData((char*)data, file.size());
 
@@ -109,14 +108,6 @@ int main(int argc, char *argv[])
     // Disable it because we already support HDPI display natively
     qunsetenv("QT_DEVICE_PIXEL_RATIO");
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 8, 0)
-    QString renderer = QString(GRAPHICAL_RENDERER);
-    if(renderer == "software")
-       QQuickWindow::setSceneGraphBackend(QSGRendererInterface::Software);
-    else if(renderer == "opengl")
-       QQuickWindow::setSceneGraphBackend(QSGRendererInterface::OpenGL);
-#endif
-    
     QApplication app(argc, argv);
     app.setOrganizationName("KDE");
     app.setApplicationName(GCOMPRIS_APPLICATION_NAME);
@@ -149,9 +140,9 @@ int main(int argc, char *argv[])
     parser.addVersionOption();
     QCommandLineOption exportActivitiesAsSQL("export-activities-as-sql", "Export activities as SQL");
     parser.addOption(exportActivitiesAsSQL);
-	QCommandLineOption clDefaultCursor(QStringList() << "c" << "cursor",
+    QCommandLineOption clDefaultCursor(QStringList() << "c" << "cursor",
                                        QObject::tr("Run GCompris with the default system cursor."));
-	parser.addOption(clDefaultCursor);
+    parser.addOption(clDefaultCursor);
     QCommandLineOption clNoCursor(QStringList() << "C" << "nocursor",
                                        QObject::tr("Run GCompris without cursor (touch screen mode)."));
     parser.addOption(clNoCursor);
@@ -173,15 +164,19 @@ int main(int argc, char *argv[])
     QCommandLineOption clWithKioskMode(QStringList() << "enable-kioskmode",
                                        QObject::tr("Enable the kiosk mode."));
     parser.addOption(clWithKioskMode);
+
+    QCommandLineOption clSoftwareRenderer(QStringList() << "software-renderer",
+                                       QObject::tr("Use software renderer instead of openGL (slower but should run with any graphical card, needs Qt 5.8 minimum)."));
+    parser.addOption(clSoftwareRenderer);
+    QCommandLineOption clOpenGLRenderer(QStringList() << "opengl-renderer",
+                                       QObject::tr("Use openGL renderer instead of software (faster but crash potentially depending on your graphical card)."));
+    parser.addOption(clOpenGLRenderer);
+
     parser.process(app);
 
-
-    ApplicationInfo::init();
-    ActivityInfoTree::init();
-    ApplicationSettings::init();
-    File::init();
-    Directory::init();
-    DownloadManager::init();
+    GComprisPlugin plugin;
+    plugin.registerTypes("GCompris");
+    ActivityInfoTree::registerResources();
 
     // Tell media players to stop playing, it's GCompris time
     ApplicationInfo::getInstance()->requestAudioFocus();
@@ -193,28 +188,27 @@ int main(int argc, char *argv[])
     // Getting fullscreen mode from config if exist, else true is default value
     bool isFullscreen = true;
     {
-
         if(config.contains("General/fullscreen")) {
             isFullscreen = config.value("General/fullscreen").toBool();
         }
 
-		// Set the cursor image
-		bool defaultCursor = false;
-		if(config.contains("General/defaultCursor")) {
-			defaultCursor = config.value("General/defaultCursor").toBool();
-		}
-		if(!defaultCursor && !parser.isSet(clDefaultCursor))
-			QGuiApplication::setOverrideCursor(
-						QCursor(QPixmap(":/gcompris/src/core/resource/cursor.svg"),
-								0, 0));
+        // Set the cursor image
+        bool defaultCursor = false;
+        if(config.contains("General/defaultCursor")) {
+            defaultCursor = config.value("General/defaultCursor").toBool();
+        }
+        if(!defaultCursor && !parser.isSet(clDefaultCursor))
+            QGuiApplication::setOverrideCursor(
+                                               QCursor(QPixmap(":/gcompris/src/core/resource/cursor.svg"),
+                                                       0, 0));
 
-		// Hide the cursor
-		bool noCursor = false;
-		if(config.contains("General/noCursor")) {
-			noCursor = config.value("General/noCursor").toBool();
-		}
-		if(noCursor || parser.isSet(clNoCursor))
-			QGuiApplication::setOverrideCursor(QCursor(Qt::BlankCursor));
+        // Hide the cursor
+        bool noCursor = false;
+        if(config.contains("General/noCursor")) {
+            noCursor = config.value("General/noCursor").toBool();
+        }
+        if(noCursor || parser.isSet(clNoCursor))
+            QGuiApplication::setOverrideCursor(QCursor(Qt::BlankCursor));
     }
 
     // Update execution counter
@@ -240,6 +234,23 @@ int main(int argc, char *argv[])
     if(parser.isSet(clWithKioskMode)) {
         ApplicationSettings::getInstance()->setKioskMode(true);
     }
+    if(parser.isSet(clSoftwareRenderer)) {
+        ApplicationSettings::getInstance()->setRenderer(QStringLiteral("software"));
+    }
+    if(parser.isSet(clOpenGLRenderer)) {
+        ApplicationSettings::getInstance()->setRenderer(QStringLiteral("opengl"));
+    }
+
+    // Set the renderer used
+    const QString &renderer = ApplicationSettings::getInstance()->renderer();
+    ApplicationInfo::getInstance()->setUseOpenGL(renderer != QLatin1String("software"));
+
+#if QT_VERSION >= QT_VERSION_CHECK(5, 8, 0)
+    if(renderer == QLatin1String("software"))
+       QQuickWindow::setSceneGraphBackend(QSGRendererInterface::Software);
+    else if(renderer == QLatin1String("opengl"))
+       QQuickWindow::setSceneGraphBackend(QSGRendererInterface::OpenGL);
+#endif
 
     QQmlApplicationEngine engine(QUrl("qrc:/gcompris/src/core/main.qml"));
     QObject::connect(&engine, &QQmlApplicationEngine::quit, DownloadManager::getInstance(),
@@ -254,7 +265,7 @@ int main(int argc, char *argv[])
 #endif
 
     if(parser.isSet(exportActivitiesAsSQL)) {
-        ActivityInfoTree *menuTree(qobject_cast<ActivityInfoTree*>(ActivityInfoTree::menuTreeProvider(&engine, NULL)));
+        ActivityInfoTree *menuTree(qobject_cast<ActivityInfoTree*>(ActivityInfoTree::menuTreeProvider(&engine, nullptr)));
         menuTree->exportAsSQL();
         exit(0);
     }
@@ -262,10 +273,10 @@ int main(int argc, char *argv[])
     QObject *topLevel = engine.rootObjects().value(0);
 
     QQuickWindow *window = qobject_cast<QQuickWindow *>(topLevel);
-    if (!window) {
-		qWarning("Error: Your root item has to be a Window.");
-		return -1;
-	}
+    if (window == nullptr) {
+        qWarning("Error: Your root item has to be a Window.");
+        return -1;
+    }
 
     ApplicationInfo::setWindow(window);
 
